@@ -46,8 +46,8 @@ class RunSnpDetection(object):
         self.pipeline = args.pipeline
         self.preview = True if self.pipeline == 'preview' else False
         self.logger.info(f"You are running bohra in {self.pipeline} mode.")
-        self.snippy_singularity = args.snippy_singularity
-        self.abritamr_singularity = args.abritamr_singularity
+        self.snippy_singularity = ''
+        self.abritamr_singularity = ''
         self.job_id = self._name_exists(args.job_id)
         self.logger.info(f"Job ID is set {self.job_id}")
         # path to reference and mask
@@ -70,8 +70,8 @@ class RunSnpDetection(object):
         # self.source_log_path = pathlib.Path(self.workdir, 'source.log')
         # job id
         
-        self.check_rerun()
         self.keep = True if args.keep == 'Y' else False
+        self.check_rerun()
         self.gubbins = args.gubbins 
         # other variables
         # min aln 
@@ -89,14 +89,14 @@ class RunSnpDetection(object):
         self.user = getpass.getuser()
         
         self.gubbins = False
-        self.use_singularity = args.use_singularity
+        self.use_singularity = False
         self.mdu = args.mdu
         # self.logger.info(f"{self.mdu}")
         if isinstance(args.prefillpath, str):
             self.prefillpath = args.prefillpath
         elif self.mdu:
-            self.use_singularity = True
-            self.logger.info(f"You are running bohra on mdu business - so singularity containers will be used automatically {self.use_singularity}")
+            # self.use_singularity = True
+            # self.logger.info(f"You are running bohra on mdu business - so singularity containers will be used automatically {self.use_singularity}")
             self.prefillpath = f"{pathlib.Path('/', 'home', 'seq', 'MDU', 'QC')}/"
         else:
             self.prefillpath = ''
@@ -334,7 +334,7 @@ class RunSnpDetection(object):
         # os.chdir(self.workdir)
         
         p1 = pathlib.Path(self.workdir, self.job_id, 'report')
-        p2 = pathlib.Path(self.workdir, self.job_id, f"report_{self.orignal_date}")
+        p2 = pathlib.Path(self.workdir, self.job_id, f"report_archived_{self.day}")
         if self.keep:
             self.logger.info(f"Archiving previous report files")
             cmd = f"mv {p1} {p2}"
@@ -462,7 +462,7 @@ class RunSnpDetection(object):
 
         '''
         self.logger.info(f'Checking if job is a rerun of existing job.')
-        report_path = self.workdir / self.job_id / 'report' / 'report.html'
+        report_path = self.workdir / self.job_id / 'report' / 'index.html'
         preview_path = self.workdir / self.job_id / 'report' / 'preview_distances.tab'
         # if the path is a string convert to Path
         if isinstance(report_path, str):
@@ -546,7 +546,7 @@ class RunSnpDetection(object):
             :unzipped: unzipped path
         '''
         self.logger.info(f"Checking if reference needs to be unzipped")
-        target = self.workdir / path.name.strip(suffix)
+        target = self.workdir / pathlib.Path(path).name.strip(suffix)
         
         if suffix == '.zip':
             cmd = f"unzip {path} -d {target}"
@@ -605,11 +605,31 @@ class RunSnpDetection(object):
         
         return  path.name
 
+    def check_ref_type(self, ref):
+
+        lst = []
+        record = SeqIO.parse(ref, 'genbank')
+        for r in record:
+            lst.append(r)
+        if lst != []:
+            return 'genbank'
+        else:
+            record = SeqIO.parse(ref, 'fasta')
+            for r in record:
+                lst.append(r)
+            if lst != []:
+                return 'fasta'
+            else:
+                self.logger.info(f"It seems your reference file is not a genbank or fasta file format. Please check your inputs and try again.")
+        
     def index_reference(self):
 
         ref = pathlib.Path(self.job_id , 'ref.fa')
         idx = pathlib.Path(self.job_id , 'ref.fa.fai')
-        if '.fa' not in self.ref:
+        if f"{pathlib.Path(self.ref).suffix}" in ['.gz','zip']:
+                    self.ref = pathlib.Path(self.unzip_files(self.ref, f"{self.ref.suffix}"))
+        ref_type = self.check_ref_type(ref = self.ref)
+        if ref_type == 'genbank':
             self.logger.info(f"converting {self.ref} to fasta format.")
             SeqIO.convert(f"{self.ref}", 'genbank', f"{ref}", 'fasta')
         else:
