@@ -1,5 +1,5 @@
-import toml, pathlib, subprocess, sys, datetime, pandas, re, numpy
-
+import toml, pathlib, subprocess, sys, datetime, pandas, re, numpy, jinja2
+from snakemake import shell
 
 def write_tables(table):
     '''
@@ -11,12 +11,7 @@ def write_tables(table):
     data = open(path).readlines()
     # for header
     header = data[0].split('\t')
-    # if 'mlst' in f"{table}":
-    #     # number of alleles
-    #     length = len(data[1].split('\t'))-2
-    #     header = ['Isolate', 'Scheme', 'ST']
-    #     for l in range(1,length):
-    #         header.append(f"Allele_{l}")
+    
     if 'distances.tab' in table:
         tablehead = [f"<th class='{column}-head'>{column}</th>" for column in header]
     else:
@@ -75,7 +70,6 @@ def preview_distances_tab(table):
     for d in range(1,len(data)):
         row = [f"<tr>"]
         l = data[d].split()
-        print(l)
         header.append(l[0])
         for i in range(len(l)):
         # print(d)  
@@ -256,20 +250,8 @@ def get_dict(pipeline):
 
 def fill_vals(td, pipeline):
 
-    # if pipeline == 'preview':
-    #     for t in range(len(td)):
-    #         if td[t]['type'] == 'matrix':
-    #             td[t]['head'], td[t]['body'] = preview_distances_tab(table=td[t]['file'])
-    
-    # # snpdistances = []
-    # # snpdensity = []
-    # else:
-    print(range(len(td)))
-    # print(td[10])
     for t in range(len(td)):
-        # print(t)
-        # print(td[t])
-
+    
         # TODO if table add a modal modal + link and link will be title lowercase with hyphen
         if td[t]['type'] == 'table':
             td[t]['head'], td[t]['body'] = write_tables(table=td[t]['file'])
@@ -285,7 +267,6 @@ def fill_vals(td, pipeline):
         if td[t]['type'] == 'summary':
             # generate_summary()
             td[t]['head'], td[t]['body'] = write_tables(table = td[t]['file'])
-        print(t)
     return td
 
 def get_software_versions(software):
@@ -453,7 +434,15 @@ def write_toml(data, output):
     with open(output, 'wt') as f:
         toml.dump(data, f)
     
-def main(inputs, pipeline,job_id, assembler = ''):
+def main(inputs, pipeline,job_id, resources, assembler = ''):
+
+    p = pathlib.Path('.')
+    print(p)
+    reporthtml = pathlib.Path('report.html')
+    print(reporthtml)
+    # path to html template
+    indexhtml = pathlib.Path(resources,'index.html') # replace with template
+    print(indexhtml)
     # initialise dictionary
     # print(pipeline)
     print(inputs)
@@ -493,22 +482,31 @@ def main(inputs, pipeline,job_id, assembler = ''):
         data['newick'] = get_tree_string(pipeline = pipeline)
     elif pipeline in ['s', 'sa', 'preview', 'all']:
         data['newick'] = get_tree_string(pipeline = pipeline)
+
     
 
 # newick = newick, display = display,tables = tables,td = td, job_id = job_id, pipeline = pipeline, snpdistances=snpdistances, snpdensity = snpdensity, modaltables = modaltables, date = date
     td = fill_vals(td=td, pipeline = pipeline)
     data['td'] = td
+    report_template = jinja2.Template(pathlib.Path(indexhtml).read_text())
+    reporthtml.write_text(report_template.render(data))
     # print(data)
     write_toml(data = data, output = 'report.toml')    
 
+pipeline = snakemake.params.pipeline
+print(pipeline)
+job_id = snakemake.params.job_id
+assembler = snakemake.params.assembler
+inputs = snakemake.input
+resources = snakemake.params.template_path
 
-if __name__ == '__main__':
-    
-    main(inputs = sys.argv[4:], pipeline = f"{sys.argv[1]}", job_id = f"{sys.argv[2]}",assembler = f"{sys.argv[3]}")
-    
-
-
-
+# pipeline = 'preview'
+# job_id = 'test'
+# assembler = ''
+# inputs = 'preview.toml'
+# resources = '/home/khhor/dev/bohra/bohra/templates'
+# {params.pipeline} {params.job_id} {params.assembler} {input}
+main(pipeline = pipeline, inputs = inputs, job_id= job_id, assembler= assembler, resources = resources)
 # mash triangle -C *.msh
 
 # mash sketch -m 5 -s 10000 -r -o 2019-12803-6/sketch -I 2019-12803-6 -C 2019-12803-6/R1.fq.gz 2019-12803-6/R1.fq.gz
\ No newline at end of file
