@@ -1,4 +1,5 @@
 import toml, pathlib, subprocess, sys
+from snakemake import shell
 
 def generate_mv_cmd(iostring):
 
@@ -22,12 +23,12 @@ def main(inputs):
     for i in inputs:
         iostring = get_io(i)
         cmd = generate_mv_cmd(iostring)
+        print(f"Moving out files : {cmd}")
         p = run_cmd(cmd)
     
 
 
-if __name__ == '__main__':
-    
-    main(inputs = sys.argv[1:])
+inputs = snakemake.input    
+main(inputs = inputs)
     
 
